#
# spec file for package ghc-unicode-transforms
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name unicode-transforms
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.4.0.1
Release:        5.6
Summary:        Unicode normalization
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/4.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-unicode-data-devel
BuildRequires:  ghc-unicode-data-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-deepseq-prof
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-prof
BuildRequires:  ghc-split-devel
BuildRequires:  ghc-split-prof
%endif

%description
Fast Unicode 14.0.0 normalization in Haskell (NFC, NFKC, NFD, NFKD).

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc Changelog.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Tue Oct 24 2023 Peter Simons <psimons@suse.com>
- Update unicode-transforms to version 0.4.0.1 revision 4.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Tue Mar 14 2023 Peter Simons <psimons@suse.com>
- Update unicode-transforms to version 0.4.0.1 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Oct 20 2022 Peter Simons <psimons@suse.com>
- Update unicode-transforms to version 0.4.0.1 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Sep 14 2022 Peter Simons <psimons@suse.com>
- Update unicode-transforms to version 0.4.0.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Mar 21 2022 Peter Simons <psimons@suse.com>
- Update unicode-transforms to version 0.4.0.1.
  [#]# 0.4.0.1 (March 2022)
  * Support text-icu == 0.8.* in tests
  * Support unicode-data == 0.3.*
* Sun Jan  9 2022 Peter Simons <psimons@suse.com>
- Update unicode-transforms to version 0.4.0 revision 1.
  [#]# 0.4.0 (November 2021)
  * Bump `unicode-data` to `0.2`
  * Allow `text 2.0`
  * Update to Unicode version 14.0.0
  * Drop support for GHC 7.10
* Sun Nov 21 2021 Ondřej Súkup <mimi.vx@gmail.com>
- relax overspecified constraints on unicode-data
* Fri Jul 23 2021 psimons@suse.com
- Update unicode-transforms to version 0.3.8.
  [#]# 0.3.8
  * Allow ghc-prim 0.7
  * Extract `unicode-data` into its own package
  * Depend on the latest stable `text`
* Thu Apr 22 2021 psimons@suse.com
- Update unicode-transforms to version 0.3.7.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Oct 13 2020 psimons@suse.com
- Update unicode-transforms to version 0.3.7.1.
  [#]# 0.3.7.1
  * Fix x32 build
* Tue Aug 18 2020 psimons@suse.com
- Update unicode-transforms to version 0.3.7.
  [#]# 0.3.7
  * Significant performance improvements
  * Update to Unicode version 13.0.0
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Mon Jun 17 2019 psimons@suse.com
- Update unicode-transforms to version 0.3.6.
  [#]# 0.3.6
  * Update to Unicode version 12.1.0
  * Update Quickcheck dependency version bounds
  * Test with GHC 8.6.5
* Sat Nov 17 2018 psimons@suse.com
- Update unicode-transforms to version 0.3.5.
  [#]# 0.3.5
  * Update dependency version bounds
  * Test with GHC 8.6.2
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update unicode-transforms to version 0.3.4.
  * GHC 8.4.1 support
  * GHC 8.2.1 support
* Thu Jul 27 2017 psimons@suse.com
- Update to version 0.3.2.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 0.2.1 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 0.1.0.1 revision 0 with cabal2obs.
